@@ -6,7 +6,7 @@
 ### ** Examples
 
 suppressPackageStartupMessages(library(sf))
-library(lwgeom)
+suppressPackageStartupMessages(library(lwgeom))
 nc = st_read(system.file("gpkg/nc.gpkg", package="sf"), quiet = TRUE)
 st_geod_area(nc[1:3,])
 # st_area(nc[1:3,])
@@ -27,3 +27,7 @@ st_geod_covers(x[c(1,1,1)], x[c(2,2,2,2)])
 box = st_polygon(list(rbind(c(179.5,0.1), c(179.5,1), c(-179.5,1), c(-179.5,0.1), c(179.5,0.1))))
 b = st_sfc(box, crs = 4326)
 units::set_units(st_geod_area(b), km^2) # approx 111^2
+
+pt = st_point(c(30, 70))
+x = st_sfc(pole, pt, pt, crs = 4326)
+st_geod_distance(x, x)
